Introduction
############

geonum is a python library written in Python 3 for geographic calculations.
It provides intuitive objects for representing locations on Earth in terms of
longitude, latitude and altitude, as well as associated arithmetics.

geonum was developed together with the `pyplis <https://pyplis.readthedocs
.io/en/latest/>`_ library
(python plume imaging software) to provide the required tools to derive the
required measurement geometry (e.g., distance of camera to volcanic emission
plume, see e.g. `Gliss et al., 2017, Figure 3 therein <https://www.mdpi.com/2076-3263/7/4/134/htm>`__).

.. include:: _features.rst

.. include:: _copyright.rst

